@@ -224,6 +224,7 @@ gdm_local_display_factory_create_transient_display (GdmLocalDisplayFactory *fact
 {
         gboolean         ret;
         GdmDisplay      *display = NULL;
+        gboolean         is_initial = FALSE;
 
         g_return_val_if_fail (GDM_IS_LOCAL_DISPLAY_FACTORY (factory), FALSE);
 
@@ -235,6 +236,7 @@ gdm_local_display_factory_create_transient_display (GdmLocalDisplayFactory *fact
         display = gdm_local_display_new ();
         if (gdm_local_display_factory_use_wayland ())
                 g_object_set (G_OBJECT (display), "session-type", "wayland", NULL);
+        is_initial = TRUE;
 #else
         if (display == NULL) {
                 guint32 num;
@@ -248,6 +250,7 @@ gdm_local_display_factory_create_transient_display (GdmLocalDisplayFactory *fact
         g_object_set (display,
                       "seat-id", "seat0",
                       "allow-timed-login", FALSE,
+                      "is-initial", is_initial,
                       NULL);
 
         store_display (factory, display);
@@ -665,7 +668,6 @@ static void
 maybe_stop_greeter_in_background (GdmLocalDisplayFactory *factory,
                                   GdmDisplay             *display)
 {
-        g_autofree char *display_session_type = NULL;
         gboolean doing_initial_setup = FALSE;
 
         if (gdm_display_get_status (display) != GDM_DISPLAY_MANAGED) {
@@ -674,7 +676,6 @@ maybe_stop_greeter_in_background (GdmLocalDisplayFactory *factory,
         }
 
         g_object_get (G_OBJECT (display),
-                      "session-type", &display_session_type,
                       "doing-initial-setup", &doing_initial_setup,
                       NULL);
 
@@ -684,13 +685,6 @@ maybe_stop_greeter_in_background (GdmLocalDisplayFactory *factory,
                 return;
         }
 
-        /* we can only stop greeter for wayland sessions, since
-         * X server would jump back on exit */
-        if (g_strcmp0 (display_session_type, "wayland") != 0) {
-                g_debug ("GdmLocalDisplayFactory: login window is running on Xorg, so ignoring");
-                return;
-        }
-
         g_debug ("GdmLocalDisplayFactory: killing login window once its unused");
 
         g_object_set (G_OBJECT (display), "status", GDM_DISPLAY_WAITING_TO_FINISH, NULL);
